package mhayaTime

import (
	"testing"
)

func TestMhayaTime_DaysInYear(t *testing.T) {
	t.Logf("result = %v", Now().DaysInYear())
}

func TestMhayaTime_DaysInMonth(t *testing.T) {
	t.Logf("result = %v", Now().DaysInMonth())
}

func TestMhayaTime_MonthOfYear(t *testing.T) {
	t.Logf("result = %v", Now().MonthOfYear())
}

func TestMhayaTime_DayOfYear(t *testing.T) {
	t.Logf("result = %v", Now().DayOfYear())
}

func TestMhayaTime_DayOfMonth(t *testing.T) {
	t.Logf("result = %v", Now().DayOfMonth())
}

func TestMhayaTime_DayOfWeek(t *testing.T) {
	t.Logf("result = %v", Now().DayOfWeek())
}

func TestMhayaTime_WeekOfYear(t *testing.T) {
	t.Logf("result = %v", Now().WeekOfYear())
}

func TestMhayaTime_WeekOfMonth(t *testing.T) {
	t.Logf("result = %v", Now().WeekOfMonth())
}

func TestMhayaTime_Year(t *testing.T) {
	t.Logf("result = %v", Now().Year())
}

func TestMhayaTime_Quarter(t *testing.T) {
	t.Logf("result = %v", Now().Quarter())
}

func TestMhayaTime_Month(t *testing.T) {
	t.Logf("result = %v", Now().Month())
}

func TestMhayaTime_Week(t *testing.T) {
	t.Logf("result = %v", Now().Week())
}

func TestMhayaTime_Day(t *testing.T) {
	t.Logf("result = %v", Now().Day())
}

func TestMhayaTime_Hour(t *testing.T) {
	t.Logf("result = %v", Now().Hour())
}

func TestMhayaTime_Minute(t *testing.T) {
	t.Logf("result = %v", Now().Minute())
}

func TestMhayaTime_Second(t *testing.T) {
	t.Logf("result = %v", Now().Second())
}

func TestMhayaTime_Millisecond(t *testing.T) {
	t.Logf("result = %v", Now().Millisecond())
}

func TestMhayaTime_Microsecond(t *testing.T) {
	t.Logf("result = %v", Now().Microsecond())
}

func TestMhayaTime_Nanosecond(t *testing.T) {
	t.Logf("result = %v", Now().Nanosecond())
}

func TestMhayaTime_Timezone(t *testing.T) {
	t.Logf("result = %v", Now().Timezone())
}
